@@ -3,14 +3,14 @@
 #' @title Install fastai
 #' @param version specify version
 #' @param gpu installation of gpu
-#' @param cuda_version if gpu true, then cuda version is required. By default it is 10.1
+#' @param cuda_version if gpu true, then cuda version is required. By default it is 10
 #' @param overwrite will install all the dependencies
 #' @param extra_pkgs character vector of additional packages
 #' @importFrom reticulate py_install
 #' @param TPU official way to install Pytorch-XLA 1.7
 #' @return None
 #' @export
-install_fastai <- function(version, gpu = FALSE, cuda_version = '10.1', overwrite = FALSE,
+install_fastai <- function(version, gpu = FALSE, cuda_version = '10', overwrite = FALSE,
                            extra_pkgs = c('timm','fastinference[interp]'),
                            TPU = FALSE) {
   # extensions
@@ -61,20 +61,16 @@ install_fastai <- function(version, gpu = FALSE, cuda_version = '10.1', overwrit
   }
 
   # linux
-  cuda_linux = c('torch==1.7.1+cu92 torchvision==0.8.2+cu92 torchaudio==0.7.2 -f https://download.pytorch.org/whl/torch_stable.html',
-                 'torch==1.7.1+cu101 torchvision==0.8.2+cu101 torchaudio==0.7.2 -f https://download.pytorch.org/whl/torch_stable.html',
-                 'torch==1.7.1 torchvision==0.8.2 torchaudio==0.7.2',
-                 'torch==1.7.1+cu110 torchvision==0.8.2+cu110 torchaudio===0.7.2 -f https://download.pytorch.org/whl/torch_stable.html')
-  linux_cpu = c('torch==1.7.1+cpu torchvision==0.8.2+cpu torchaudio==0.7.2 -f https://download.pytorch.org/whl/torch_stable.html')
+  cuda_linux = c('torch torchvision torchaudio',
+                 'torch==1.9.0+cu111 torchvision==0.10.0+cu111 torchaudio==0.9.0 -f https://download.pytorch.org/whl/torch_stable.html')
+  linux_cpu = c('torch==1.9.0+cpu torchvision==0.10.0+cpu torchaudio==0.9.0 -f https://download.pytorch.org/whl/torch_stable.html')
 
-  xla = "-U cloud-tpu-client==0.10 https://storage.googleapis.com/tpu-pytorch/wheels/torch_xla-1.7-cp36-cp36m-linux_x86_64.whl"
+  xla = "cloud-tpu-client==0.10 torch==1.9.0 https://storage.googleapis.com/tpu-pytorch/wheels/torch_xla-1.9-cp37-cp37m-linux_x86_64.whl tensorboard-plugin-profile"
 
   # windows
-  cuda_windows = c('torch==1.7.1+cu92 torchvision==0.8.2+cu92 torchaudio==0.7.2 -f https://download.pytorch.org/whl/torch_stable.html',
-                   'torch==1.7.1+cu101 torchvision==0.8.2+cu101 torchaudio===0.7.2 -f https://download.pytorch.org/whl/torch_stable.html',
-                   'torch===1.7.1 torchvision===0.8.2 torchaudio===0.7.2 -f https://download.pytorch.org/whl/torch_stable.html',
-                   'torch===1.7.1+cu110 torchvision===0.8.2+cu110 torchaudio===0.7.2 -f https://download.pytorch.org/whl/torch_stable.html')
-  cpu_windows = c('torch==1.7.1+cpu torchvision==0.8.2+cpu torchaudio===0.7.2 -f https://download.pytorch.org/whl/torch_stable.html')
+  cuda_windows = c('torch==1.9.0+cu102 torchvision==0.10.0+cu102 torchaudio===0.9.0 -f https://download.pytorch.org/whl/torch_stable.html',
+                   'torch==1.9.0+cu111 torchvision==0.10.0+cu111 torchaudio===0.9.0 -f https://download.pytorch.org/whl/torch_stable.html')
+  cpu_windows = c('torch torchvision torchaudio')
 
   if('torch' %in% required_py_pkgs ) {
     torch_r = 'torch' %in% required_py_pkgs
@@ -104,17 +100,11 @@ install_fastai <- function(version, gpu = FALSE, cuda_version = '10.1', overwrit
     if(py_av) {
 
       if (os() %in% 'linux' & !length(required_py_pkgs) == 0 & !TPU) {
-        if(os() %in% 'linux' & gpu & cuda_version %in% '9.2' & torch_r & !length(required_py_pkgs) == 0) {
+        if (os() %in% 'linux' & gpu & cuda_version %in% '10' & torch_r & !length(required_py_pkgs) == 0) {
           py_install(packages = c(required_py_pkgs, cuda_linux[1]), pip = TRUE)
 
-        } else if (os() %in% 'linux' & gpu & cuda_version %in% '10.1' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_linux[2]), pip = TRUE)
-
-        } else if (os() %in% 'linux' & gpu & cuda_version %in% '10.2' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_linux[3]), pip = TRUE)
-
         } else if (os() %in% 'linux' & gpu & cuda_version %in% '11' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_linux[4]), pip = TRUE)
+          py_install(packages = c(required_py_pkgs, cuda_linux[2]), pip = TRUE)
 
         } else if(!gpu & torch_r & !length(required_py_pkgs) == 0) {
           py_install(packages = c(linux_cpu, required_py_pkgs), pip = TRUE)
@@ -137,17 +127,11 @@ install_fastai <- function(version, gpu = FALSE, cuda_version = '10.1', overwrit
       }
 
       if (os() %in% 'windows' & !length(required_py_pkgs) == 0 & torch_r & !length(required_py_pkgs) == 0) {
-        if(os() %in% 'windows' & gpu & cuda_version %in% '9.2') {
-          #print(cuda_windows[1])
+        if (os() %in% 'windows' & gpu & cuda_version %in% '10' & torch_r & !length(required_py_pkgs) == 0) {
           py_install(packages = c(required_py_pkgs, cuda_windows[1]), pip = TRUE)
-        } else if (os() %in% 'windows' & gpu & cuda_version %in% '10.1' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_windows[2]), pip = TRUE)
-
-        } else if (os() %in% 'windows' & gpu & cuda_version %in% '10.2' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_windows[3]), pip = TRUE)
 
         } else if (os() %in% 'windows' & gpu & cuda_version %in% '11' & torch_r & !length(required_py_pkgs) == 0) {
-          py_install(packages = c(required_py_pkgs, cuda_windows[4]), pip = TRUE)
+          py_install(packages = c(required_py_pkgs, cuda_windows[2]), pip = TRUE)
 
         } else if(!gpu & torch_r & !length(required_py_pkgs) == 0) {
           py_install(packages = c(cpu_windows, required_py_pkgs), pip = TRUE)
@@ -163,7 +147,7 @@ install_fastai <- function(version, gpu = FALSE, cuda_version = '10.1', overwrit
       }
 
       if (os() %in% 'mac' & !length(required_py_pkgs) == 0 & torch_r) {
-        py_install(packages = c('torch==1.7.1 torchvision==0.8.2 torchaudio==0.7.2', required_py_pkgs), pip = TRUE)
+        py_install(packages = c('torch torchvision torchaudio', required_py_pkgs), pip = TRUE)
 
       } else if (os() %in% 'mac' & !length(required_py_pkgs) == 0 & !torch_r){
         py_install(packages = c(required_py_pkgs), pip = TRUE)
