@@ -17,6 +17,19 @@ test_succeeds <- function(desc, expr) {
   })
 }
 
+os_win_skip <- function() {
+  if (os()=='windows')
+    skip("skip windows")
+}
+
+test_succeeds_windows <- function(desc, expr) {
+  test_that(desc, {
+    skip_if_no_fastai_core()
+    skip_if_32bit()
+    os_win_skip()
+    expect_error(force(expr), NA)
+  })
+}
 
 
 
